﻿/*:
 * @target MZ
 * @plugindesc Plugin to add a command that sets the entire party to auto-battle mode during combat.
 * @author Malomi
 * @url https://gendaigoyaku.com/
 * 
 * @param commandName
 * @text commandName
 * @desc Please name the command
 * @default Auto Battle
 * 
 * @help
 * ----------------------------------------------------------------------------
 * AutoBattleCommand.js
 * ----------------------------------------------------------------------------
 * This plugin adds a command that sets the entire party to auto-battle mode.
 * You can freely change the command name.
 * ----------------------------------------------------------------------------
 * License:
 * This is the MIT License. 
 * It can be used for both commercial and non-commercial purposes.
 * ----------------------------------------------------------------------------
 */

/*:ja
 * @target MZ
 * @plugindesc 戦闘中にパーティー全員が自動戦闘モードになるコマンドを追加するプラグイン
 * @author まろみ
 * @url https://gendaigoyaku.com/
 * 
 * @param commandName
 * @text コマンド名
 * @desc コマンド名を変更できます。
 * @default 全員突撃
 * 
 * @help
 * ----------------------------------------------------------------------------
 * AutoBattleCommand.js
 * ----------------------------------------------------------------------------
 * パーティー全員が自動戦闘モードになるコマンドを追加します。
 * コマンド名は自由に変更できます。
 * ----------------------------------------------------------------------------
 * 利用規約:
 * 商用・非商用問わず利用可能です。
 * ----------------------------------------------------------------------------
 */

(() => {
    const pluginName = "AutoBattleCommand";
    const parameters = PluginManager.parameters(pluginName);
    const commandName = String(parameters['commandName'] || 'Auto Battle');

    let originalAutoBattleStates = [];

    const _Window_PartyCommand_makeCommandList = Window_PartyCommand.prototype.makeCommandList;
    Window_PartyCommand.prototype.makeCommandList = function () {
        _Window_PartyCommand_makeCommandList.call(this);
        this.addCommand(commandName, 'autoBattle');
    };

    const _Scene_Battle_createPartyCommandWindow = Scene_Battle.prototype.createPartyCommandWindow;
    Scene_Battle.prototype.createPartyCommandWindow = function () {
        _Scene_Battle_createPartyCommandWindow.call(this);
        this._partyCommandWindow.setHandler('autoBattle', this.commandAutoBattle.bind(this));
    };

    Scene_Battle.prototype.commandAutoBattle = function () {
        originalAutoBattleStates = $gameParty.members().map(member => member.isAutoBattle());
        $gameParty.members().forEach(member => {
            member._autoBattle = true;
        });
        BattleManager.selectNextCommand();
    };

    const _Game_Actor_isAutoBattle = Game_Actor.prototype.isAutoBattle;
    Game_Actor.prototype.isAutoBattle = function () {
        return this._autoBattle || _Game_Actor_isAutoBattle.call(this);
    };

    const _BattleManager_endBattle = BattleManager.endBattle;
    BattleManager.endBattle = function (result) {
        _BattleManager_endBattle.call(this, result);
        $gameParty.members().forEach((member, index) => {
            member._autoBattle = originalAutoBattleStates[index];
        });
    };
})();
